/**
 * Default tool parameters used in xpanderAI tool configuration.
 *
 * These parameters define the structure of request payloads for tools, including
 * query, path, and body parameters, as well as specifying required fields for
 * each parameter type.
 */
export declare const DEFAULT_TOOL_PARAMETERS: Readonly<{
    /** Specifies the type of tool parameters structure. */
    type: "object";
    /** List of required top-level parameters. */
    required: never[];
    /** Detailed properties of tool parameters. */
    properties: {
        /** Query parameters for the tool, structured as an object. */
        query_params: {
            type: string;
            properties: {};
            required: never[];
        };
        /** Path parameters for the tool, structured as an object. */
        path_params: {
            type: string;
            properties: {};
            required: never[];
        };
        /** Body parameters for the tool, structured as an object. */
        body_params: {
            type: string;
            properties: {};
            required: never[];
        };
    };
}>;
/** Prefix for identifying local tools in xpanderAI. */
export declare const LOCAL_TOOL_PREFIX = "xpLocal_";
export declare enum OverSizedResponseTool {
    GetFullResponse = "xp_get_full_response",
    SearchInTheResponse = "xp_search_in_the_response",
    SkipOrContinue = "xp_skip_or_continue"
}
export declare const OVERSIZED_RESPONSE_TOOLS: ({
    type: string;
    function: {
        name: OverSizedResponseTool;
        description: string;
        parameters: {
            type: string;
            properties: {
                bodyParams?: undefined;
            };
            required?: undefined;
            additionalProperties?: undefined;
        };
    };
} | {
    type: string;
    function: {
        name: OverSizedResponseTool;
        description: string;
        parameters: {
            type: string;
            properties: {
                bodyParams: {
                    type: string;
                    properties: {
                        phrase: {
                            type: string;
                            description: string;
                        };
                    };
                    required: string[];
                    additionalProperties: boolean;
                };
            };
            required: string[];
            additionalProperties: boolean;
        };
    };
})[];
export declare const OVERSIZED_RESPONSE_TOOL_NAMES: string[];
