import { Agent } from './Agent';
import { SourceNodeType } from '../../types/agents';
import { Configuration } from '../Configuration';
/**
 * Manages a collection of Agent instances in xpanderAI, providing methods to list,
 * retrieve, and initialize specific agents including custom agents.
 */
export declare class Agents {
    configuration: Configuration;
    /** Collection of Agent instances managed by this class. */
    agentsList: Agent[];
    constructor(configuration: Configuration);
    /**
     * Retrieves the list of agents. If `refetch` is true, it re-fetches the list
     * from the API even if agents are already loaded.
     * @param refetch - If true, forces a re-fetch of the agent list from the API.
     * @returns Array of Agent instances.
     */
    list(refetch?: boolean): Agent[];
    /**
     * Retrieves an agent by ID and initializes it with the given source node type.
     * @param agentId - The ID of the agent to retrieve.
     * @param sourceNodeType - The source node type for the agent, default is SDK.
     * @returns The requested Agent instance.
     */
    get(agentId: string, sourceNodeType?: SourceNodeType): Agent;
    /**
     * Retrieves the custom agent instance, initializing it with the given source node type.
     * @param sourceNodeType - The source node type for the custom agent, default is SDK.
     * @returns The custom Agent instance.
     */
    getCustomAgent(sourceNodeType?: SourceNodeType): Agent;
}
