import { BaseLLMProvider } from './baseProvider';
import { LLMProvider } from '../../constants/llmProvider';
import { ToolCall } from '../../core/toolCalls';
/**
 * Handles interaction with OpenAI SDK, processing responses to extract tool calls.
 */
export declare class BaseOpenAISDKHandler extends BaseLLMProvider {
    /**
     * Determines if this handler should manage the specified LLM provider.
     * @param llmProvider - The LLM provider to check.
     * @returns True if the handler should manage the provider, otherwise false.
     */
    static shouldHandle(llmProvider: LLMProvider): boolean;
    /**
     * Extracts tool calls from an OpenAI LLM response.
     * @param llmResponse - The response object from the OpenAI LLM.
     * @returns An array of ToolCall objects extracted from the response.
     * @throws Error if the response format is invalid.
     */
    static extractToolCalls(llmResponse: Record<string, any>): ToolCall[];
}
